==> openshift-model-operator-5.4.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/NodeStatusBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class NodeStatusBuilder extends io.fabric8.openshift.api.model.operator.v1.NodeStatusFluentImpl<io.fabric8.openshift.api.model.operator.v1.NodeStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.NodeStatus,io.fabric8.openshift.api.model.operator.v1.NodeStatusBuilder> {

    io.fabric8.openshift.api.model.operator.v1.NodeStatusFluent<?> fluent;
    java.lang.Boolean validationEnabled;

    public NodeStatusBuilder() {
        this(true);
    }

    public NodeStatusBuilder(java.lang.Boolean validationEnabled) {
        this(new NodeStatus(), validationEnabled);
    }

    public NodeStatusBuilder(io.fabric8.openshift.api.model.operator.v1.NodeStatusFluent<?> fluent) {
        this(fluent, true);
    }

    public NodeStatusBuilder(io.fabric8.openshift.api.model.operator.v1.NodeStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
        this(fluent, new NodeStatus(), validationEnabled);
    }

    public NodeStatusBuilder(io.fabric8.openshift.api.model.operator.v1.NodeStatusFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.NodeStatus instance) {
        this(fluent, instance, true);
    }

    public NodeStatusBuilder(io.fabric8.openshift.api.model.operator.v1.NodeStatusFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.NodeStatus instance,java.lang.Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withCurrentRevision(instance.getCurrentRevision()); 
        fluent.withLastFailedRevision(instance.getLastFailedRevision()); 
        fluent.withLastFailedRevisionErrors(instance.getLastFailedRevisionErrors()); 
        fluent.withNodeName(instance.getNodeName()); 
        fluent.withTargetRevision(instance.getTargetRevision()); 
        this.validationEnabled = validationEnabled; 
    }

    public NodeStatusBuilder(io.fabric8.openshift.api.model.operator.v1.NodeStatus instance) {
        this(instance,true);
    }

    public NodeStatusBuilder(io.fabric8.openshift.api.model.operator.v1.NodeStatus instance,java.lang.Boolean validationEnabled) {
        this.fluent = this; 
        this.withCurrentRevision(instance.getCurrentRevision()); 
        this.withLastFailedRevision(instance.getLastFailedRevision()); 
        this.withLastFailedRevisionErrors(instance.getLastFailedRevisionErrors()); 
        this.withNodeName(instance.getNodeName()); 
        this.withTargetRevision(instance.getTargetRevision()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.openshift.api.model.operator.v1.NodeStatus build() {
        NodeStatus buildable = new NodeStatus(fluent.getCurrentRevision(),fluent.getLastFailedRevision(),fluent.getLastFailedRevisionErrors(),fluent.getNodeName(),fluent.getTargetRevision());
        return buildable;
    }

    public boolean equals(java.lang.Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        NodeStatusBuilder that = (NodeStatusBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> openshift-model-operator-5.7.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/NodeStatusBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class NodeStatusBuilder extends io.fabric8.openshift.api.model.operator.v1.NodeStatusFluentImpl<io.fabric8.openshift.api.model.operator.v1.NodeStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.NodeStatus,io.fabric8.openshift.api.model.operator.v1.NodeStatusBuilder> {

    io.fabric8.openshift.api.model.operator.v1.NodeStatusFluent<?> fluent;
    java.lang.Boolean validationEnabled;

    public NodeStatusBuilder() {
        this(true);
    }

    public NodeStatusBuilder(java.lang.Boolean validationEnabled) {
        this(new NodeStatus(), validationEnabled);
    }

    public NodeStatusBuilder(io.fabric8.openshift.api.model.operator.v1.NodeStatusFluent<?> fluent) {
        this(fluent, true);
    }

    public NodeStatusBuilder(io.fabric8.openshift.api.model.operator.v1.NodeStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
        this(fluent, new NodeStatus(), validationEnabled);
    }

    public NodeStatusBuilder(io.fabric8.openshift.api.model.operator.v1.NodeStatusFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.NodeStatus instance) {
        this(fluent, instance, true);
    }

    public NodeStatusBuilder(io.fabric8.openshift.api.model.operator.v1.NodeStatusFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.NodeStatus instance,java.lang.Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withCurrentRevision(instance.getCurrentRevision()); 
        fluent.withLastFailedCount(instance.getLastFailedCount()); 
        fluent.withLastFailedRevision(instance.getLastFailedRevision()); 
        fluent.withLastFailedRevisionErrors(instance.getLastFailedRevisionErrors()); 
        fluent.withLastFailedTime(instance.getLastFailedTime()); 
        fluent.withNodeName(instance.getNodeName()); 
        fluent.withTargetRevision(instance.getTargetRevision()); 
        this.validationEnabled = validationEnabled; 
    }

    public NodeStatusBuilder(io.fabric8.openshift.api.model.operator.v1.NodeStatus instance) {
        this(instance,true);
    }

    public NodeStatusBuilder(io.fabric8.openshift.api.model.operator.v1.NodeStatus instance,java.lang.Boolean validationEnabled) {
        this.fluent = this; 
        this.withCurrentRevision(instance.getCurrentRevision()); 
        this.withLastFailedCount(instance.getLastFailedCount()); 
        this.withLastFailedRevision(instance.getLastFailedRevision()); 
        this.withLastFailedRevisionErrors(instance.getLastFailedRevisionErrors()); 
        this.withLastFailedTime(instance.getLastFailedTime()); 
        this.withNodeName(instance.getNodeName()); 
        this.withTargetRevision(instance.getTargetRevision()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.openshift.api.model.operator.v1.NodeStatus build() {
        NodeStatus buildable = new NodeStatus(fluent.getCurrentRevision(),fluent.getLastFailedCount(),fluent.getLastFailedRevision(),fluent.getLastFailedRevisionErrors(),fluent.getLastFailedTime(),fluent.getNodeName(),fluent.getTargetRevision());
        return buildable;
    }

    public boolean equals(java.lang.Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        NodeStatusBuilder that = (NodeStatusBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
